﻿using System;
using System.Windows.Forms;  // requires ref to System.Windows.Forms dll
using System.Drawing;        // requires ref to System.Drawing dll


// IMGtoClipboard - Michael A. Covington 2018 - Open source

// Given an image file as a command line argument,
// creates an HTML IMG tag with width and height
// and places it on the clipboard.  If no width or
// height can be extracted, the clipboard is left empty.

// This program is used as a right-click option on image files
// as enabled by the Registry code shown below.

// The IMG tag includes the file name without the
// full path because it will presumably end up
// in the same directory as the web page that refers
// to it.

// This is compiled as a windowed application but has no main window.
// It performs i/o through its command line argument and the clipboard.

/*
 
    Installation:

    Place IMGtoClipboard.exe in a directory such as C:\Program Files (x86)\Covington Innovations\IMGtoClipboard

    Place the following information in the Registry (shown here in REGEDIT export format):

----------------------------------------------------------------------------
Windows Registry Editor Version 5.00    

[HKEY_CLASSES_ROOT\SystemFileAssociations\image\shell\IMGtoClipboard]
@="Create IMG tag on clipboard"

[HKEY_CLASSES_ROOT\SystemFileAssociations\image\shell\IMGtoClipboard\Command]
@="\"C:\\Program Files (x86)\\Covington Innovations\\IMGtoClipboard\\IMGtoClipboard.exe\" \"%1\""
----------------------------------------------------------------------------

    The installer project creates an installer that does this.

 */

namespace IMGtoClipboard
{
    class Program
    {
        [STAThread]
        static void Main(string[] args)
        {
            if (args.Length < 1) return;

            string fname = args[0];

            Clipboard.Clear();

            try
            {
                var image = Image.FromFile(fname);
                string result = "<img " +
                                "src=\"" + System.IO.Path.GetFileName(fname) +
                                "\" " +
                                "height=\"" + image.Height.ToString() +
                                "\" " +
                                "width=\"" + image.Width.ToString() +
                                "\" alt=\"Picture\" />";

                Clipboard.SetText(result);
            }
            catch 
            {
                return;   // "He dies, and makes no sign." - Shakespeare
            }

        }
    }
}
